.. _all-salt.states:

===========================
Full list of builtin states
===========================

.. currentmodule:: salt.states

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    alias
    cmd
    cron
    file
    gem
    git
    group
    host
    kmod
    mount
    mysql_database
    mysql_grants
    mysql_user
    network
    pip
    pkg
    postgres_database
    rvm
    selinux
    service
    ssh_auth
    ssh_known_hosts
    sysctl
    user
    virtualenv
